@@ -16,6 +16,9 @@ import datetime
 from future.utils import with_metaclass
 from itertools import islice
 from e6xdb.exceptions import ProgrammingError
+import logging
+
+_logger = logging.getLogger(__name__)
 
 
 class DBAPICursor(with_metaclass(abc.ABCMeta, object)):
@@ -105,6 +108,7 @@ class DBAPICursor(with_metaclass(abc.ABCMeta, object)):
             return None
         else:
             if self._rownumber == 1000:
+                _logger.info("Commons - Breaking the loop after 1000 records")
                 return None
             self._rownumber += 1
             return self._data.popleft()
